pitchtools.Accidental
=====================

.. abjad-lineage:: abjad.tools.pitchtools.Accidental.Accidental.Accidental

.. autoclass:: abjad.tools.pitchtools.Accidental.Accidental.Accidental
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.alphabetic_accidental_abbreviation
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.is_adjusted
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.semitones
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.storage_format
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.symbolic_accidental_string
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__nonzero__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__sub__
   :noindex:
